summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chromeos/input_method/input_method_manager_impl.h
diff options
context:
space:
mode:
authornona@chromium.org <nona@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-09 04:50:23 +0000
committernona@chromium.org <nona@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-05-09 04:50:23 +0000
commitaef1af4b193560aa51e9aaa858ae41a7e92b5c3a (patch)
tree996057f591a6168fb9da0512fa9c5fd0b082594a /chrome/browser/chromeos/input_method/input_method_manager_impl.h
parent6e536cdf138d65ede0844654966a0c0ed0cfd430 (diff)
downloadchromium_src-aef1af4b193560aa51e9aaa858ae41a7e92b5c3a.zip
chromium_src-aef1af4b193560aa51e9aaa858ae41a7e92b5c3a.tar.gz
chromium_src-aef1af4b193560aa51e9aaa858ae41a7e92b5c3a.tar.bz2
Do not enable extension IME just after installation.
This CL inverts the meaning of filtered extension IMEs preferences. With this CL any extension IME won't be enabled just after it's installed. This is preparation of dropping Extension IME button from language options. After that, I will introduce better extension IME selection based on user's preferred languages. BUG=180094 TEST=Manually checked Review URL: https://chromiumcodereview.appspot.com/14870004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@199110 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/chromeos/input_method/input_method_manager_impl.h')
-rw-r--r--chrome/browser/chromeos/input_method/input_method_manager_impl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/chromeos/input_method/input_method_manager_impl.h b/chrome/browser/chromeos/input_method/input_method_manager_impl.h
index 57ee61c..53a6961 100644
--- a/chrome/browser/chromeos/input_method/input_method_manager_impl.h
+++ b/chrome/browser/chromeos/input_method/input_method_manager_impl.h
@@ -80,7 +80,7 @@ class InputMethodManagerImpl : public InputMethodManager,
virtual void RemoveInputMethodExtension(const std::string& id) OVERRIDE;
virtual void GetInputMethodExtensions(
InputMethodDescriptors* result) OVERRIDE;
- virtual void SetFilteredExtensionImes(std::vector<std::string>* ids) OVERRIDE;
+ virtual void SetEnabledExtensionImes(std::vector<std::string>* ids) OVERRIDE;
virtual bool SwitchToNextInputMethod() OVERRIDE;
virtual bool SwitchToPreviousInputMethod() OVERRIDE;
virtual bool SwitchInputMethod(const ui::Accelerator& accelerator) OVERRIDE;
@@ -171,8 +171,8 @@ class InputMethodManagerImpl : public InputMethodManager,
// The active input method ids cache.
std::vector<std::string> active_input_method_ids_;
- // The list of IMEs that are filtered from the IME list.
- std::vector<std::string> filtered_extension_imes_;
+ // The list of enabled extension IMEs.
+ std::vector<std::string> enabled_extension_imes_;
// For screen locker. When the screen is locked, |previous_input_method_|,
// |current_input_method_|, and |active_input_method_ids_| above are copied